@@ -180,7 +180,7 @@ clustermq_class <- R6::R6Class(
       try(
         if_any(
           self$any_upcoming_jobs(),
-          self$worker_list$send_wait(),
+          self$worker_list$send(NULL),
           self$shut_down_worker()
         )
       )
@@ -238,7 +238,10 @@ clustermq_class <- R6::R6Class(
     run_clustermq = function() {
       on.exit({
         if (!is.null(self$worker_list)) {
-          try(self$worker_list$cleanup())
+          self$scheduler$backoff$reset()
+          while (!suppressMessages(self$worker_list$cleanup())) {
+            self$scheduler$backoff$wait()
+          }
         }
       })
       self$start_workers()
