@@ -89,9 +89,9 @@ network_class <- R6::R6Class(
       }
       vertices <- self$vertices
       edges <- self$edges
-      vertices <- vertices[vertices$name %in% self$names, , drop = FALSE] # nolint
-      edges <- edges[edges$from %in% self$names, , drop = FALSE] # nolint
-      edges <- edges[edges$to %in% self$names, , drop = FALSE] # nolint
+      vertices <- vertices[vertices$name %in% self$names, , drop = FALSE]
+      edges <- edges[edges$from %in% self$names, , drop = FALSE]
+      edges <- edges[edges$to %in% self$names, , drop = FALSE]
       self$vertices <- vertices
       self$edges <- edges
     },
@@ -102,22 +102,26 @@ network_class <- R6::R6Class(
         return()
       }
       edges <- self$edges
-      vertices <- vertices[vertices$name %in% allow, , drop = FALSE] # nolint
-      edges <- edges[edges$from %in% allow, , drop = FALSE] # nolint
-      edges <- edges[edges$to %in% allow, , drop = FALSE] # nolint
+      vertices <- vertices[vertices$name %in% allow, , drop = FALSE]
+      edges <- edges[edges$from %in% allow, , drop = FALSE]
+      edges <- edges[edges$to %in% allow, , drop = FALSE]
       self$vertices <- vertices
       self$edges <- edges
     },
     exclude_vertices = function() {
       vertices <- self$vertices
-      exclude <- tar_tidyselect_eval(self$exclude, vertices$name)
+      exclude <- tar_tidyselect_eval(
+        self$exclude,
+        vertices$name,
+        strict = FALSE
+      )
       if (is.null(exclude)) {
         return()
       }
       edges <- self$edges
-      vertices <- vertices[!(vertices$name %in% exclude), , drop = FALSE] # nolint
-      edges <- edges[!(edges$from %in% exclude), , drop = FALSE] # nolint
-      edges <- edges[!(edges$to %in% exclude), , drop = FALSE] # nolint
+      vertices <- vertices[!(vertices$name %in% exclude), , drop = FALSE]
+      edges <- edges[!(edges$from %in% exclude), , drop = FALSE]
+      edges <- edges[!(edges$to %in% exclude), , drop = FALSE]
       self$vertices <- vertices
       self$edges <- edges
     },
@@ -128,12 +132,12 @@ network_class <- R6::R6Class(
       }
       self$update_targets()
       vertices <- rbind(self$vertices_targets, self$vertices_imports)
-      vertices <- vertices[!duplicated(vertices$name), , drop = FALSE] # nolint
-      vertices <- vertices[order(vertices$name), , drop = FALSE] # nolint
+      vertices <- vertices[!duplicated(vertices$name), , drop = FALSE]
+      vertices <- vertices[order(vertices$name), , drop = FALSE]
       edges <- rbind(self$edges_imports, self$edges_targets)
-      edges <- edges[edges$from %in% vertices$name, , drop = FALSE] # nolint
-      edges <- edges[edges$to %in% vertices$name, , drop = FALSE] # nolint
-      edges <- edges[order(edges$from), , drop = FALSE] # nolint
+      edges <- edges[edges$from %in% vertices$name, , drop = FALSE]
+      edges <- edges[edges$to %in% vertices$name, , drop = FALSE]
+      edges <- edges[order(edges$from), , drop = FALSE]
       self$vertices <- vertices
       self$edges <- edges
       self$shortcut_vertices()
