@@ -13,13 +13,11 @@ value_count_slices.tar_vector <- function(value) {
 
 #' @export
 value_produce_slice.tar_vector <- function(value, index) {
-  # nolint
-  vctrs::vec_slice(x = value$object, i = index)
+  slice_vector(x = value$object, i = index)
 }
 
 #' @export
 value_produce_aggregate.tar_vector <- function(value, objects) {
-  # nolint
   tar_vec_c(objects)
 }
 
