@@ -28,8 +28,9 @@
 #'   The edges data frame has one row for every edge and columns `to` and
 #'   `from` to mark the starting and terminating vertices.
 #' @inheritParams tar_outdated
-#' @param targets_only Logical, whether to restrict the output to just targets
-#'   (`FALSE`) or to also include imported global functions and objects.
+#' @param targets_only `TRUE` to restrict the output to just
+#'   the actual targets in the pipeline, `FALSE` to include
+#'   imported global functions and objects as well.
 #' @param names Names of targets. The graph visualization will operate
 #'   only on these targets (and unless `shortcut` is `TRUE`,
 #'   all the targets upstream as well). Selecting a small subgraph
@@ -40,18 +41,26 @@
 #'   `tidyselect` expression like [any_of()] or [starts_with()]
 #'   from `tidyselect` itself, or [tar_described_as()] to select target names
 #'   based on their descriptions.
-#' @param allow Optional, define the set of allowable vertices in the graph.
+#' @param allow Optional, the set of allowable vertices in the graph.
+#'   Supplied as `NULL` or a `tidyselect` expression like [any_of()]
+#'   or [starts_with()].
+#'
 #'   Unlike `names`, `allow` is invoked only after the graph is mostly
 #'   resolved, so it will not speed up execution.
 #'   Set to `NULL` to allow all vertices in the pipeline and environment
-#'   (default). Otherwise, you can supply symbols or
-#'   `tidyselect` helpers like [starts_with()].
-#' @param exclude Optional, define the set of exclude vertices from the graph.
+#'   (default).
+#' @param exclude Optional, the set of exclude vertices from the graph.
+#'   Supplied as `NULL` or a `tidyselect` expression like [any_of()]
+#'   or [starts_with()].
+#'
 #'   Unlike `names`, `exclude` is invoked only after the graph is mostly
 #'   resolved, so it will not speed up execution.
-#'   Set to `NULL` to exclude no vertices.
-#'   Otherwise, you can supply symbols or `tidyselect`
-#'   helpers like [any_of()] and [starts_with()].
+#'
+#'   Unlike all other `tidyselect`-powered arguments in `targets`,
+#'   `exclude` lets you supply target names
+#'   that do not necessarily exist in the graph.
+#'
+#'   Set `exclude` to `NULL` to exclude no vertices.
 #' @param outdated Logical, whether to show colors to distinguish outdated
 #'   targets from up-to-date targets. (Global functions and objects
 #'   still show these colors.) Looking for outdated targets
@@ -91,14 +100,9 @@ tar_network <- function(
 ) {
   force(envir)
   tar_assert_lgl(targets_only)
-  tar_config_assert_reporter_outdated(reporter)
   reporter <- tar_outdated_reporter(reporter)
   tar_assert_callr_function(callr_function)
   tar_assert_list(callr_arguments)
-  tar_assert_dbl(seconds_reporter)
-  tar_assert_scalar(seconds_reporter)
-  tar_assert_none_na(seconds_reporter)
-  tar_assert_ge(seconds_reporter, 0)
   targets_arguments <- list(
     path_store = store,
     targets_only = targets_only,
@@ -107,8 +111,7 @@ tar_network <- function(
     allow_quosure = rlang::enquo(allow),
     exclude_quosure = rlang::enquo(exclude),
     outdated = outdated,
-    reporter = reporter,
-    seconds_reporter = seconds_reporter
+    reporter = reporter
   )
   callr_outer(
     targets_function = tar_network_inner,
@@ -131,8 +134,7 @@ tar_network_inner <- function(
   allow_quosure,
   exclude_quosure,
   outdated,
-  reporter,
-  seconds_reporter
+  reporter
 ) {
   meta <- meta_init(path_store = path_store)
   progress <- progress_init(path_store = path_store)
@@ -147,8 +149,7 @@ tar_network_inner <- function(
     allow = allow_quosure,
     exclude = exclude_quosure,
     outdated = outdated,
-    reporter = reporter,
-    seconds_reporter = seconds_reporter
+    reporter = reporter
   )
   inspection$update()
   list(
