@@ -70,10 +70,13 @@ tar_assert_correct_fields <- function(
 tar_assert_target_dag <- function(x, msg = NULL) {
   if (!inherits(x, "igraph") || !igraph::is_dag(x)) {
     default <- paste(
-      "dependency graph contains a cycle.",
-      "If target x depends on target y, then",
-      "target y must not depend on target x,",
-      "either directly or indirectly."
+      "the dependency graph contains a cycle.",
+      "That means at least one target, function, or global object",
+      "appears to depends on itself, either directly or indirectly.",
+      "To debug, run targets::tar_igraph()",
+      "to get the igraph object of the dependency graph,",
+      "then run igraph::find_cycle() to find a cycle.",
+      "find_cycle() requires igraph >= 2.2.0."
     )
     tar_throw_validate(msg %|||% default)
   }
@@ -653,7 +656,7 @@ tar_assert_store_noninvalidating <- function(store, threshold, prompt) {
 tar_assert_target <- function(x, msg = NULL) {
   msg <- msg %|||%
     paste(
-      "Found a non-target object in the target list.",
+      "Found a non-target-definition object in the target list.",
       "The target script file (default: _targets.R)",
       "must end with a list of tar_target() objects (recommended)",
       "or a tar_pipeline() object (deprecated)."
@@ -665,10 +668,13 @@ tar_assert_target <- function(x, msg = NULL) {
 #' @rdname tar_assert
 tar_assert_target_list <- function(x) {
   msg <- paste(
-    "Expected a list of target objects, but the object is not a list.",
-    "Are you missing a target list at the end of your target script file?",
+    "Expected a list of target definition objects,",
+    "but the object is not a list.",
+    "Are you missing a target list at the",
+    "end of your target script file?",
     "The target script file (e.g. _targets.R)",
-    "must end with a list of tar_target() objects."
+    "must end with a list of target definition",
+    "objects produced by tar_target() or similar."
   )
   tar_assert_list(x, msg = msg)
   map(x, tar_assert_target)
@@ -821,7 +827,7 @@ tar_deprecate_seconds_interval <- function(seconds_interval) {
 
 tar_warn_prefix <- function() {
   tar_warn_deprecate(
-    "Please supply an explicit prefix for you target object data ",
+    "Please supply an explicit prefix for you target definition object data ",
     "and metadata. The prefix should be unique to your `targets` project. ",
     "In the future, `targets` will begin requiring explicitly ",
     "user-supplied prefixes. This warning was added on 2023-08-24 ",
